##  Support Channels
**Note**
For SAP customers, the configuration of support channels is not available. Users can submit support requests using built-in support in SAP LeanIX or using the SAP for Me portal. For details, see [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support?locale=en-US&state=PRODUCTION&version=CLOUD "If you encounter issues, have questions, or need assistance with SAP LeanIX, our support team is here to help. You can contact support directly within SAP LeanIX or submit a request in the SAP for Me portal.").
You can configure support channels using the following settings:
  * Support e-mail: The email address to be used when clicking the Support button. If relevant, you can specify your organization's internal email address, which enables you to review support requests internally before submitting them to SAP LeanIX.
  * Support URL: The URL of the website that opens when clicking the Support button. We recommend using the URL for the SAP customer portal: [https://me.sap.com/![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/").


Using a combination of these settings, you can configure how support channels work:
  * To hide the Support button, leave both Support e-mail and Support URL empty.
  * To point the Support button to a specific email address, leave the Support URL field empty and specify the address in Support e-mail.
  * To point the Support button to a specific URL, leave the Support e-mail field empty and specify the URL in Support URL.
